==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Namespaces/namespacellarp_1_1bits.md <==
---
title: llarp::bits

---

# llarp::bits



## Functions

|                | Name           |
| -------------- | -------------- |
| template <typename Int_t \> <br>constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**(Int_t i) |
| constexpr std::size_t | **[count_bits_128](Namespaces/namespacellarp_1_1bits.md#function-count-bits-128)**(const [uint128_t](Classes/structllarp_1_1uint128__t.md) & i) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([huint32_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([nuint32_t](Classes/structllarp_1_1nuint__t.md) x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([huint128_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([nuint128_t](Classes/structllarp_1_1nuint__t.md) x) |
| template <typename InputIt \> <br>constexpr std::size_t | **[count_array_bits_impl](Namespaces/namespacellarp_1_1bits.md#function-count-array-bits-impl)**(InputIt begin, InputIt end) |
| template <typename T \> <br>constexpr std::size_t | **[count_array_bits](Namespaces/namespacellarp_1_1bits.md#function-count-array-bits)**(const T & array) |


## Functions Documentation

### function count_bits

```cpp
template <typename Int_t >
constexpr std::size_t count_bits(
    Int_t i
)
```


### function count_bits_128

```cpp
constexpr std::size_t count_bits_128(
    const uint128_t & i
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    huint32_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    nuint32_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    huint128_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    nuint128_t x
)
```


### function count_array_bits_impl

```cpp
template <typename InputIt >
constexpr std::size_t count_array_bits_impl(
    InputIt begin,
    InputIt end
)
```


### function count_array_bits

```cpp
template <typename T >
constexpr std::size_t count_array_bits(
    const T & array
)
```






-------------------------------

Updated on 2022-05-31 at 02:25:19 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Namespaces/namespacellarp_1_1bits.md <==
---
title: llarp::bits

---

# llarp::bits



## Functions

|                | Name           |
| -------------- | -------------- |
| template <typename Int_t \> <br>constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**(Int_t i) |
| constexpr std::size_t | **[count_bits_128](Namespaces/namespacellarp_1_1bits.md#function-count-bits-128)**(const [uint128_t](Classes/structllarp_1_1uint128__t.md) & i) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([huint32_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**(nuint32_t x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**([huint128_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr std::size_t | **[count_bits](Namespaces/namespacellarp_1_1bits.md#function-count-bits)**(nuint128_t x) |
| template <typename InputIt \> <br>constexpr std::size_t | **[count_array_bits_impl](Namespaces/namespacellarp_1_1bits.md#function-count-array-bits-impl)**(InputIt begin, InputIt end) |
| template <typename T \> <br>constexpr std::size_t | **[count_array_bits](Namespaces/namespacellarp_1_1bits.md#function-count-array-bits)**(const T & array) |


## Functions Documentation

### function count_bits

```cpp
template <typename Int_t >
constexpr std::size_t count_bits(
    Int_t i
)
```


### function count_bits_128

```cpp
constexpr std::size_t count_bits_128(
    const uint128_t & i
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    huint32_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    nuint32_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    huint128_t x
)
```


### function count_bits

```cpp
constexpr std::size_t count_bits(
    nuint128_t x
)
```


### function count_array_bits_impl

```cpp
template <typename InputIt >
constexpr std::size_t count_array_bits_impl(
    InputIt begin,
    InputIt end
)
```


### function count_array_bits

```cpp
template <typename T >
constexpr std::size_t count_array_bits(
    const T & array
)
```






-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
